# swehockey_scraper
Package to scrape swehockey for ice hockey data and stats

## Getting started
Package can be installed with pip  
```pip install swehockey_scraper```

In python, import module with  
```import swehockey.swehockey_scraper as swe```

See description of functions in package with  
```help(swe)```

Functions can be used together and input and output is linked. 
